  django-fernet-fields-v2
  ------------------------------------------------------------------------------------------------------------------------
  [Fernet](https://cryptography.io/en/latest/fernet/) symmetric encryption for Django model fields, using the
  [cryptography](https://cryptography.io/en/latest/) library and supports Django \>=3.2 .
  `django-fernet-fields-v2` supports [Django](http://www.djangoproject.com/) 3.2 and later on Python 3.8, 3.9, 3.10 and 3.11
  Only PostgreSQL, SQLite, and MySQL are tested, but any Django database backend
  with support for `BinaryField` should work.
  Getting Help

Fork of <https://github.com/orcasgit/django-fernet-fields> . See docs
there. The only changes made here are to support Django 4.

This app is available on [PyPI][pypi] and can be installed with `django-fernet-fields-v2`.

# Contributing

See the [contributing
docs](https://github.com/MichelML/django-fernet-fields/blob/master/CONTRIBUTING.rst).

[pypi]: https://pypi.org/project/django-fernet-fields-v2/
